==> haskell-vector-hashtables-0.1.2.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-hashtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-hashtables
version:              0.1.2.1
visibility:           public
id:                   vector-hashtables-0.1.2.1-2a2Ep2i4pixBi4VbKRNACQ
key:                  vector-hashtables-0.1.2.1-2a2Ep2i4pixBi4VbKRNACQ
license:              BSD-3-Clause
copyright:            2016-2024 klapaucius, swamp_agr
maintainer:           klapaucius, swamp_agr, ArtemPelenitsyn
author:               klapaucius
homepage:             https://github.com/klapaucius/vector-hashtables#readme
synopsis:             Efficient vector-based mutable hashtables implementation.
description:
    This package provides efficient vector-based hashtable implementation similar to .NET Generic Dictionary implementation (at the time of 2015).

    See "Data.Vector.Hashtables" for documentation.

category:             Data
abi:                  315bfc4756c6b9d2161861d4c30a4bbc
exposed:              True
exposed-modules:
    Data.Primitive.PrimArray.Utils Data.Vector.Hashtables
    Data.Vector.Hashtables.Internal
    Data.Vector.Hashtables.Internal.Mask

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-hashtables-0.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-hashtables-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-hashtables-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-hashtables
hs-libraries:         HSvector-hashtables-0.1.2.1-2a2Ep2i4pixBi4VbKRNACQ
depends:
    base-4.17.2.1 hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    primitive-0.8.0.0-1110YmBHzhAERV5HY7EG3e
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:
    /usr/share/doc/haskell-vector-hashtables/html/vector-hashtables.haddock

haddock-html:         /usr/share/doc/haskell-vector-hashtables/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-hashtables-0.1.2.1-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-hashtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-hashtables
version:              0.1.2.1
visibility:           public
id:                   vector-hashtables-0.1.2.1-1eGgXaQuJk12azUL01jlzt
key:                  vector-hashtables-0.1.2.1-1eGgXaQuJk12azUL01jlzt
license:              BSD-3-Clause
copyright:            2016-2024 klapaucius, swamp_agr
maintainer:           klapaucius, swamp_agr, ArtemPelenitsyn
author:               klapaucius
homepage:             https://github.com/klapaucius/vector-hashtables#readme
synopsis:             Efficient vector-based mutable hashtables implementation.
description:
    This package provides efficient vector-based hashtable implementation similar to .NET Generic Dictionary implementation (at the time of 2015).

    See "Data.Vector.Hashtables" for documentation.

category:             Data
abi:                  edc408ba105d18816b56f8c8d2d6fb44
exposed:              True
exposed-modules:
    Data.Primitive.PrimArray.Utils Data.Vector.Hashtables
    Data.Vector.Hashtables.Internal
    Data.Vector.Hashtables.Internal.Mask

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-hashtables-0.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-hashtables-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-hashtables-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-hashtables
hs-libraries:         HSvector-hashtables-0.1.2.1-1eGgXaQuJk12azUL01jlzt
depends:
    base-4.17.2.1 hashable-1.4.4.0-D3M5e9EeJxCJTqzfO7ugwa
    primitive-0.9.0.0-1uQl5SMm5FQ52SaicTkt1Y
    vector-0.13.2.0-G0g5gCprguQ6M58H7uQE53

haddock-interfaces:
    /usr/share/doc/haskell-vector-hashtables/html/vector-hashtables.haddock

haddock-html:         /usr/share/doc/haskell-vector-hashtables/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
